User: james
Date: 05/02/03 17:30:43
Modified: xemacs/src ChangeLog config.h.in device-x.c eval.c frame.c
gui-gtk.c gui-x.c lisp.h redisplay.c
Log:
Don't define this to c_this, and rename variables currently named this.
See xemacs-patches message with ID <psbrb1ehjl.fsf(a)diannao.ittc.ku.edu>.
Revision Changes Path
1.786 +13 -0 XEmacs/xemacs/src/ChangeLog
(In the diff below, changes in quantity of whitespace are not shown.)
Index: ChangeLog
===================================================================
RCS file: /pack/xemacscvs/XEmacs/xemacs/src/ChangeLog,v
retrieving revision 1.785
retrieving revision 1.786
diff -u -b -r1.785 -r1.786
--- ChangeLog 2005/02/03 16:14:02 1.785
+++ ChangeLog 2005/02/03 16:30:33 1.786
@@ -1,3 +1,16 @@
+2005-02-03 Jerry James <james(a)xemacs.org>
+
+ * config.h.in: Remove #define this c_this.
+ * device-x.c (construct_name_list): Rename this -> this_widget.
+ * eval.c (wants_debugger): Rename this -> curr.
+ * frame.c (delete_frame_internal): Rename this -> this_frame.
+ * gui-gtk.c (ungcpro_popup_callbacks): Rename this -> this_callback.
+ * gui-gtk.c (get_gcpro_popup_callbacks): Ditto.
+ * gui-x.c (gcpro_popup_callbacks): Ditto.
+ * gui-x.c (ungcpro_popup_callbacks): Ditto.
+ * lisp.h: Remove #undef this and #defin this c_this.
+ * redisplay.c (generate_fstring_runes): Rename this -> this_str.
+
2005-02-01 Jerry James <james(a)xemacs.org>
* dumper.c: Olivier Galibert's changes to enable dumping data via
1.96 +0 -1 XEmacs/xemacs/src/config.h.in
(In the diff below, changes in quantity of whitespace are not shown.)
Index: config.h.in
===================================================================
RCS file: /pack/xemacscvs/XEmacs/xemacs/src/config.h.in,v
retrieving revision 1.95
retrieving revision 1.96
diff -u -b -r1.95 -r1.96
--- config.h.in 2004/11/04 23:06:17 1.95
+++ config.h.in 2005/02/03 16:30:35 1.96
@@ -1018,7 +1018,6 @@
# if defined (__cplusplus)
/* Avoid C++ keywords used as ordinary C identifiers */
# define new c_new
-# define this c_this
# define catch c_catch
# define EXTERN_C extern "C"
1.61 +5 -4 XEmacs/xemacs/src/device-x.c
(In the diff below, changes in quantity of whitespace are not shown.)
Index: device-x.c
===================================================================
RCS file: /pack/xemacscvs/XEmacs/xemacs/src/device-x.c,v
retrieving revision 1.60
retrieving revision 1.61
diff -u -b -r1.60 -r1.61
--- device-x.c 2005/01/24 23:33:50 1.60
+++ device-x.c 2005/02/03 16:30:35 1.61
@@ -1238,16 +1238,17 @@
char *fake_class, char *name, char *class_)
{
char *stack [100][2];
- Widget this;
+ Widget this_widget;
int count = 0;
char *name_tail, *class_tail;
if (widget)
{
- for (this = widget; this; this = XtParent (this))
+ for (this_widget = widget; this_widget;
+ this_widget = XtParent (this_widget))
{
- stack [count][0] = this->core.name;
- stack [count][1] = XtClass (this)->core_class.class_name;
+ stack [count][0] = this_widget->core.name;
+ stack [count][1] = XtClass (this_widget)->core_class.class_name;
count++;
}
count--;
1.88 +3 -3 XEmacs/xemacs/src/eval.c
(In the diff below, changes in quantity of whitespace are not shown.)
Index: eval.c
===================================================================
RCS file: /pack/xemacscvs/XEmacs/xemacs/src/eval.c,v
retrieving revision 1.87
retrieving revision 1.88
diff -u -b -r1.87 -r1.88
--- eval.c 2005/02/03 16:14:05 1.87
+++ eval.c 2005/02/03 16:30:36 1.88
@@ -587,10 +587,10 @@
while (CONSP (conditions))
{
- Lisp_Object this, tail;
- this = XCAR (conditions);
+ Lisp_Object curr, tail;
+ curr = XCAR (conditions);
for (tail = list; CONSP (tail); tail = XCDR (tail))
- if (EQ (XCAR (tail), this))
+ if (EQ (XCAR (tail), curr))
return 1;
conditions = XCDR (conditions);
}
1.68 +11 -11 XEmacs/xemacs/src/frame.c
(In the diff below, changes in quantity of whitespace are not shown.)
Index: frame.c
===================================================================
RCS file: /pack/xemacscvs/XEmacs/xemacs/src/frame.c,v
retrieving revision 1.67
retrieving revision 1.68
diff -u -b -r1.67 -r1.68
--- frame.c 2005/02/03 16:14:06 1.67
+++ frame.c 2005/02/03 16:30:36 1.68
@@ -1445,12 +1445,12 @@
FRAME_LOOP_NO_BREAK (frmcons, devcons, concons)
{
- Lisp_Object this = XCAR (frmcons);
+ Lisp_Object this_frame = XCAR (frmcons);
- if (! EQ (this, frame)
+ if (! EQ (this_frame, frame)
&& EQ (frame, (WINDOW_FRAME
(XWINDOW
- (FRAME_MINIBUF_WINDOW (XFRAME (this)))))))
+ (FRAME_MINIBUF_WINDOW (XFRAME (this_frame)))))))
{
/* We've found another frame whose minibuffer is on
this frame. */
@@ -1467,14 +1467,14 @@
FRAME_LOOP_NO_BREAK (frmcons, devcons, concons)
{
- Lisp_Object this = XCAR (frmcons);
+ Lisp_Object this_frame = XCAR (frmcons);
- if (! EQ (this, frame))
+ if (! EQ (this_frame, frame))
{
struct device *devcons_d = XDEVICE (XCAR (devcons));
if (EQ (frame, DEVMETH_OR_GIVEN (devcons_d, get_frame_parent,
- (XFRAME (this)),
+ (XFRAME (this_frame)),
Qnil)))
/* We've found a popup frame whose parent is this frame. */
gui_error
@@ -1715,22 +1715,22 @@
CONSOLE_FRAME_LOOP_NO_BREAK (frmcons, devcons, con)
{
- Lisp_Object this;
+ Lisp_Object this_frame;
struct frame *f1;
- this = XCAR (frmcons);
- f1 = XFRAME (this);
+ this_frame = XCAR (frmcons);
+ f1 = XFRAME (this_frame);
/* Consider only frames on the same console
and only those with minibuffers. */
if (FRAME_HAS_MINIBUF_P (f1))
{
- frame_with_minibuf = this;
+ frame_with_minibuf = this_frame;
if (FRAME_MINIBUF_ONLY_P (f1))
goto double_break_2;
}
- frame_on_same_console = this;
+ frame_on_same_console = this_frame;
}
double_break_2:
1.8 +5 -5 XEmacs/xemacs/src/gui-gtk.c
(In the diff below, changes in quantity of whitespace are not shown.)
Index: gui-gtk.c
===================================================================
RCS file: /pack/xemacscvs/XEmacs/xemacs/src/gui-gtk.c,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -b -r1.7 -r1.8
--- gui-gtk.c 2004/07/07 12:01:07 1.7
+++ gui-gtk.c 2005/02/03 16:30:37 1.8
@@ -57,19 +57,19 @@
ungcpro_popup_callbacks (GUI_ID id)
{
Lisp_Object lid = make_int (id);
- Lisp_Object this = assq_no_quit (lid, Vpopup_callbacks);
- Vpopup_callbacks = delq_no_quit (this, Vpopup_callbacks);
+ Lisp_Object this_callback = assq_no_quit (lid, Vpopup_callbacks);
+ Vpopup_callbacks = delq_no_quit (this_callback, Vpopup_callbacks);
}
Lisp_Object
get_gcpro_popup_callbacks (GUI_ID id)
{
Lisp_Object lid = make_int (id);
- Lisp_Object this = assq_no_quit (lid, Vpopup_callbacks);
+ Lisp_Object this_callback = assq_no_quit (lid, Vpopup_callbacks);
- if (!NILP (this))
+ if (!NILP (this_callback))
{
- return (XCDR (this));
+ return (XCDR (this_callback));
}
return (Qnil);
}
1.39 +8 -8 XEmacs/xemacs/src/gui-x.c
(In the diff below, changes in quantity of whitespace are not shown.)
Index: gui-x.c
===================================================================
RCS file: /pack/xemacscvs/XEmacs/xemacs/src/gui-x.c,v
retrieving revision 1.38
retrieving revision 1.39
diff -u -b -r1.38 -r1.39
--- gui-x.c 2004/11/04 23:06:35 1.38
+++ gui-x.c 2005/02/03 16:30:37 1.39
@@ -111,12 +111,12 @@
gcpro_popup_callbacks (LWLIB_ID id)
{
Lisp_Object lid = make_int (id);
- Lisp_Object this = assq_no_quit (lid, Vpopup_callbacks);
+ Lisp_Object this_callback = assq_no_quit (lid, Vpopup_callbacks);
- if (!NILP (this))
+ if (!NILP (this_callback))
{
- free_list (XCDR (this));
- XCDR (this) = snarf_widget_values_for_gcpro (id);
+ free_list (XCDR (this_callback));
+ XCDR (this_callback) = snarf_widget_values_for_gcpro (id);
}
else
Vpopup_callbacks = Fcons (Fcons (lid, snarf_widget_values_for_gcpro (id)),
@@ -130,11 +130,11 @@
ungcpro_popup_callbacks (LWLIB_ID id)
{
Lisp_Object lid = make_int (id);
- Lisp_Object this = assq_no_quit (lid, Vpopup_callbacks);
+ Lisp_Object this_callback = assq_no_quit (lid, Vpopup_callbacks);
- assert (!NILP (this));
- free_list (XCDR (this));
- Vpopup_callbacks = delq_no_quit (this, Vpopup_callbacks);
+ assert (!NILP (this_callback));
+ free_list (XCDR (this_callback));
+ Vpopup_callbacks = delq_no_quit (this_callback, Vpopup_callbacks);
}
int
1.124 +0 -6 XEmacs/xemacs/src/lisp.h
(In the diff below, changes in quantity of whitespace are not shown.)
Index: lisp.h
===================================================================
RCS file: /pack/xemacscvs/XEmacs/xemacs/src/lisp.h,v
retrieving revision 1.123
retrieving revision 1.124
diff -u -b -r1.123 -r1.124
--- lisp.h 2005/02/03 07:11:28 1.123
+++ lisp.h 2005/02/03 16:30:37 1.124
@@ -516,8 +516,6 @@
we don't want by creating overloaded versions of them and declaring them
private. */
-#undef this
-
class Bytecount;
class Bytebpos;
class Bytexpos;
@@ -942,8 +940,6 @@
{ return Bytecount (x - y); }
#endif
-#define this c_this
-
#endif /* __cplusplus */
/* Counts of elements */
@@ -3235,9 +3231,7 @@
gcpro (const gcpro& g) : next (g.next), var (g.var), nvars (g.nvars) { }
gcpro& operator= (const gcpro& g) { next = g.next; var = g.var;
nvars = g.nvars;
-#undef this
return *this;}
-#define this c_this
~gcpro () { assert (!next); }
#endif /* defined (__cplusplus) && defined (ERROR_CHECK_GC) */
};
1.96 +18 -18 XEmacs/xemacs/src/redisplay.c
(In the diff below, changes in quantity of whitespace are not shown.)
Index: redisplay.c
===================================================================
RCS file: /pack/xemacscvs/XEmacs/xemacs/src/redisplay.c,v
retrieving revision 1.95
retrieving revision 1.96
diff -u -b -r1.95 -r1.96
--- redisplay.c 2005/02/03 16:14:08 1.95
+++ redisplay.c 2005/02/03 16:30:38 1.96
@@ -4106,20 +4106,20 @@
/* A string. Add to the display line and check for %-constructs
within it. */
- Ibyte *this = XSTRING_DATA (elt);
+ Ibyte *this_str = XSTRING_DATA (elt);
- while ((pos < max_pos || max_pos == -1) && *this)
+ while ((pos < max_pos || max_pos == -1) && *this_str)
{
- Ibyte *last = this;
+ Ibyte *last = this_str;
- while (*this && *this != '%')
- this++;
+ while (*this_str && *this_str != '%')
+ this_str++;
- if (this != last)
+ if (this_str != last)
{
/* No %-construct */
Charcount size =
- bytecount_to_charcount (last, this - last);
+ bytecount_to_charcount (last, this_str - last);
if (size <= *offset)
*offset -= size;
@@ -4134,32 +4134,32 @@
*offset = 0;
}
}
- else /* *this == '%' */
+ else /* *this_str == '%' */
{
Charcount spec_width = 0;
- this++; /* skip over '%' */
+ this_str++; /* skip over '%' */
/* We can't allow -ve args due to the "%-" construct.
* Argument specifies minwidth but not maxwidth
* (maxwidth can be specified by
* (<negative-number> . <stuff>) modeline elements)
*/
- while (isdigit (*this))
+ while (isdigit (*this_str))
{
- spec_width = spec_width * 10 + (*this - '0');
- this++;
+ spec_width = spec_width * 10 + (*this_str - '0');
+ this_str++;
}
spec_width += pos;
- if (*this == 'M')
+ if (*this_str == 'M')
{
pos = generate_fstring_runes (w, data, pos, spec_width,
max_pos, Vglobal_mode_string,
depth, max_pixsize, findex,
type, offset, cur_ext);
}
- else if (*this == '-')
+ else if (*this_str == '-')
{
Charcount num_to_add;
@@ -4186,9 +4186,9 @@
pos = add_string_to_fstring_db_runes
(data, (const Ibyte *) "-", pos, pos, max_pos);
}
- else if (*this != 0)
+ else if (*this_str != 0)
{
- Ichar ch = itext_ichar (this);
+ Ichar ch = itext_ichar (this_str);
Ibyte *str;
Charcount size;
@@ -4215,9 +4215,9 @@
}
}
/* NOT this++. There could be any sort of character at
the current position. */
- INC_IBYTEPTR (this);
+ INC_IBYTEPTR (this_str);
}
if (max_pixsize > 0)
@@ -4215,9 +4215,9 @@
}
}
- /* NOT this++. There could be any sort of character at
+ /* NOT this_str++. There could be any sort of character at
the current position. */